==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'Neniu foruma mesaĝo',

	// B
	'bouton_radio_articles_futurs' => 'nur al estontaj artikoloj (neniu ago ĉe la datenbazo).',
	'bouton_radio_articles_tous' => 'al ĉiuj artikoloj senescepte.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'al ĉiuj artikoloj, escepte tiuj, kies forumo estas fermita.',
	'bouton_radio_enregistrement_obligatoire' => 'Deviga memregistriĝo (la uzantoj devas aboniĝi, entajpante sian retpoŝtadreson antaŭ ol sendi kontribuaĵojn).',
	'bouton_radio_moderation_priori' => 'Apriora moderigado (kontribuaĵoj estas publikigataj nur post validigo fare de mastrumantoj).',
	'bouton_radio_modere_abonnement' => 'per abono',
	'bouton_radio_modere_posteriori' => 'aposteriore moderigata',
	'bouton_radio_modere_priori' => 'apriore moderigata',
	'bouton_radio_publication_immediate' => 'Tujpublikigo de mesaĝoj
 (la kontribuaĵoj afiŝiĝas tuj post ties sendo, la mastrumantoj povas
forviŝi ilin poste).',

	// D
	'documents_interdits_forum' => 'Dokumentoj malpermesitaj en la forumo',

	// E
	'erreur_enregistrement_message' => 'Via mesaĝo ne estis registrita pro teknika problemo.',
	'extensions_autorisees' => 'Eblaj sufiksoj :',
	'extensions_autorisees_toutes' => 'ĉiujn',

	// F
	'form_pet_message_commentaire' => 'Ĉu mesaĝon, ĉu komenton ?',
	'forum' => 'Forumo',
	'forum_acces_refuse' => 'Vi ne plu havas alir-rajton al tiuj ĉi forumoj.',
	'forum_attention_dix_caracteres' => '<b>Atentu !</b> via mesaĝo devas enhavi almenaŭ dek signojn.',
	'forum_attention_message_non_poste' => 'Atentu, vi ne afiŝis vian mesaĝon !',
	'forum_attention_nb_caracteres_mini' => '<b>Atentu !</b> Via mesaĝo enhavu almenaŭ @min@ signoj.',
	'forum_attention_trois_caracteres' => '<b>Atentu !</b> via titolo devas enhavi almenaŭ tri signojn.',
	'forum_attention_trop_caracteres' => '<b>Atentu !</b> Via mesaĝo estas tro longa (@compte@ signoj) : por esti registrita, ĝi ne preteratingu @max@ signojn.',
	'forum_avez_selectionne' => 'Vi selektis :',
	'forum_cliquer_retour' => 'Musklaku <a href=\'@retour_forum@\'>ĉi tie</a> por daŭrigi.',
	'forum_envoyer' => 'Sendi',
	'forum_forum' => 'forumo',
	'forum_info_modere' => 'Tiu ĉi forumo estas apriore moderigata : via kontribuo aperos nur post validigo fare de mastrumanto de la retejo.',
	'forum_lien_hyper' => 'Retligilo',
	'forum_message' => 'Via mesaĝo',
	'forum_message_definitif' => 'Definitiva mesaĝo : sendu al la forumo',
	'forum_message_trop_long' => 'Via mesaĝo estas tro longa. Ĝi maksimume estu 20 000 signojn longa.',
	'forum_ne_repondez_pas' => 'Ne respondu al tiu ĉi retletero, sed en la forumo ĉe la jena adreso :',
	'forum_page_url' => '(Se via mesaĝo rilatas al artikolo publikigita ĉe la reto, aŭ al paĝo donanta pli da informoj, bonvolu indiki ĉi-poste la titolon de la paĝo kaj ties ret-adreson.)',
	'forum_permalink' => 'Fiksligilo al la komento',
	'forum_poste_par' => 'Mesaĝo skribita de @parauteur@ reage al la artikolo „@titre@“.',
	'forum_poste_par_court' => 'Mesaĝo afiŝita@parauteur@.',
	'forum_poste_par_generique' => 'Mesaĝo afiŝita@parauteur@ (@objet@ „@titre@“).',
	'forum_qui_etes_vous' => 'Kiu vi estas ?',
	'forum_saisie_texte_info' => 'Tiu formularo komprenas la jenajn SPIP-markojn : <code>[-&gt;retadreso] {{grasa}} {kursiva} &lt;quote&gt; &lt;code&gt;</code> kaj HTML-markojn : <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Por krei alineoj, simple lasu malplenajn liniojn.',
	'forum_texte' => 'Teksto de via mesaĝo',
	'forum_titre' => 'Titolo',
	'forum_url' => 'Via retejo',
	'forum_valider' => 'Validigi tiun elekton',
	'forum_voir_avant' => 'Antaŭrigardi',
	'forum_votre_email' => 'Via retpoŝtadreso',
	'forum_votre_nom' => 'Via nomo',
	'forum_vous_enregistrer' => 'Por partopreni en ;
  tiu ĉi forumo, vi devas antaŭe registriĝi. Bonvolu
  indiki ĉi-sube la personan ensalutilon kiu estis
  sendita al vi. Se vi ne estas registrita, vi devas',
	'forum_vous_inscrire' => 'registriĝi.',

	// I
	'icone_bruler_message' => 'Raporti kiel trudmesaĝo',
	'icone_bruler_messages' => 'Raporti kiel trudmesaĝo',
	'icone_legitimer_message' => 'Raporti kiel taŭga mesaĝo',
	'icone_poster_message' => 'Sendi mesaĝon',
	'icone_suivi_forum' => 'Superrigardo de la publika forumo : @nb_forums@ kontribuo(j)',
	'icone_suivi_forums' => 'Superrigardi/mastrumi la forumojn',
	'icone_supprimer_message' => 'Forigi tiun mesaĝon',
	'icone_supprimer_messages' => 'Forigi tiujn mesaĝojn',
	'icone_valider_message' => 'Validigi tiun mesaĝon',
	'icone_valider_messages' => 'Validigi tiujn mesaĝojn',
	'icone_valider_repondre_message' => 'Validigi kaj respondi tiun mesaĝon',
	'info_1_message_forum' => '1 foruma mesaĝo',
	'info_activer_forum_public' => 'Por aktivigi la publikajn forumojn, bonvolu elekti ilian
 defaŭltan moderig-reĝimon :',
	'info_appliquer_choix_moderation' => 'Apliki tiun moderig-elekton :',
	'info_config_forums_prive' => 'En la privata spaco de la retejo, vi povas aktivigi plurajn tipojn de forumoj :',
	'info_config_forums_prive_admin' => 'Forumo rezervita al retejaj mastrumantoj :',
	'info_config_forums_prive_global' => 'Ĝenerala forumo, malfermita al ĉiuj redaktantoj :',
	'info_config_forums_prive_objets' => 'Forumo sub ĉiu artikolo, fulminformo, referencigita retejo, ktp :',
	'info_desactiver_forum_public' => 'Malaktivigi la uzon de la publikaj forumoj.
La publikaj forumoj estos laŭkaze unu post la alia permesitaj
 laŭ la artikoloj ; ili estos malpermesataj koncerne rubrikojn, fulm-informojn, ktp.',
	'info_envoi_forum' => 'Sendo de la forumoj al aŭtoroj de la artikoloj',
	'info_fonctionnement_forum' => 'Funkciado de la forumo :',
	'info_forcer_previsualisation_court' => 'Devigi la antaŭrigardon',
	'info_forcer_previsualisation_long' => 'Devigi la antaŭrigardon antaŭ sendo de la mesaĝo',
	'info_forums_liees_mot' => 'Mesaĝoj el forumo ligitaj al tiu ĉi vorto',
	'info_gauche_suivi_forum_2' => 'La paĝo pri <i>superkontrolo de la forumoj</i> estas mastrumilo por via retejo (kaj ne diskutejo aŭ redaktejo). Ĝi afiŝas ĉiujn kontribuaĵojn de la forumoj (de la publika spaco same kiel de la privata), kaj ebligas al vi mastrumi tiujn kontribuaĵojn.',
	'info_liens_syndiques_3' => 'forumoj',
	'info_liens_syndiques_4' => 'estas',
	'info_liens_syndiques_5' => 'forumo',
	'info_liens_syndiques_6' => 'estas',
	'info_liens_syndiques_7' => 'validigotaj',
	'info_liens_texte' => 'Ligilo(j) ene de la teksto de la mesaĝo',
	'info_liens_titre' => 'Ligilo(j) ene de la titolo de la mesaĝo',
	'info_mode_fonctionnement_defaut_forum_public' => 'Defaŭlta funkcimodo de la publikaj forumoj',
	'info_nb_messages_forum' => '@nb@ forummesaĝoj',
	'info_option_email' => 'Kiam vizitanto de la retejo sendas novan mesaĝon en la forumon
 ligitan kun artikolo, eblas retpoŝte sciigi pri tiu mesaĝo al la aŭtoroj de la artikolo. Indiku por ĉia forumo, ĉu tiun eblecon oni uzu.',
	'info_pas_de_forum' => 'neniu forumo',
	'info_question_visiteur_ajout_document_forum' => 'Se vi deziras permesi al vizitantoj kunsendi dokumentojn (bildojn, sonaĵojn...) al siaj forumaj mesaĝoj, bonvolu indiki ĉi-sube la liston de dosiernomaj sufiksoj permesitaj por la forumoj (ekz. : gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Se vi deziras permesi ĉiujn tipojn de dokumentoj konsideritaj kiel sekuraj de Spip, entajpu steleton. Por nenion permesi, nenion entajpu.',
	'info_selectionner_message' => 'Elekti la mesaĝojn :',
	'interface_formulaire' => 'Formulara interfaco',
	'interface_onglets' => 'Interfaco kun langetoj',
	'item_activer_forum_administrateur' => 'Aktivigi la forumon de la mastrumantoj',
	'item_config_forums_prive_global' => 'Aktivigi la forumon de redaktantoj',
	'item_config_forums_prive_objets' => 'Aktivigi tiujn ĉi forumojn',
	'item_desactiver_forum_administrateur' => 'Malaktivigi la forumon de la mastrumantoj',
	'item_non_config_forums_prive_global' => 'Malaktivigi la forumon de redaktantoj',
	'item_non_config_forums_prive_objets' => 'Malaktivigi tiujn ĉi forumojn',

	// L
	'label_selectionner' => 'Elekti :',
	'lien_reponse_article' => 'Respondo al la artikolo',
	'lien_reponse_breve_2' => 'Respondo al la fulm-informo',
	'lien_reponse_message' => 'Respondi al mesaĝo',
	'lien_reponse_rubrique' => 'Respondo al la rubriko',
	'lien_reponse_site_reference' => 'Respondo al la referencigita retejo',
	'lien_vider_selection' => 'Malplenigi la elekton',

	// M
	'messages_aucun' => 'Neniu',
	'messages_meme_auteur' => 'Ĉiuj mesaĝoj el tiu aŭtoro',
	'messages_meme_email' => 'Ĉiuj mesaĝoj el tiu retmesaĝo',
	'messages_meme_ip' => 'Ĉiuj mesaĝoj el tiu IP-adreso',
	'messages_off' => 'Forigitaj',
	'messages_perso' => 'Personaj',
	'messages_privadm' => 'Mastrumantoj',
	'messages_prive' => 'Privataj',
	'messages_privoff' => 'Forigitaj',
	'messages_privrac' => 'Ĝeneralaj',
	'messages_prop' => 'Proponitaj',
	'messages_publie' => 'Publikigitaj',
	'messages_spam' => 'Trudmesaĝo',
	'messages_tous' => 'Ĉiuj',

	// O
	'onglet_messages_internes' => 'Internaj mesaĝoj',
	'onglet_messages_publics' => 'Publikaj mesaĝoj',
	'onglet_messages_vide' => 'Sentekstaj mesaĝoj',

	// R
	'repondre_message' => 'Respondi al tiu mesaĝo',

	// S
	'statut_off' => 'Forigita',
	'statut_original' => 'originala',
	'statut_prop' => 'Proponita',
	'statut_publie' => 'Publikigita',
	'statut_spam' => 'Trudmesaĝo',

	// T
	'text_article_propose_publication_forum' => 'Senhezite sciigu vian opinion danke al forumo ligita al tiu artikolo (sube de la paĝo).',
	'texte_en_cours_validation' => 'Ĉi-subaj artikoloj, fulm-informoj, forumoj estas proponitaj por publikigo.',
	'texte_en_cours_validation_forum' => 'Senhezite sciigu vian opinion danke al forumoj, kiuj estas ligitaj al ili.',
	'texte_messages_publics' => 'Publikaj mesaĝoj pri :',
	'titre_cadre_forum_administrateur' => 'Privata forumo de la mastrumantoj',
	'titre_cadre_forum_interne' => 'Interna forumo',
	'titre_config_forums_prive' => 'Forumoj de la privata spaco',
	'titre_forum' => 'Forumo',
	'titre_forum_suivi' => 'Superrigardo de la forumoj',
	'titre_page_forum_suivi' => 'Superrigardo de la forumoj',
	'titre_selection_action' => 'Elekto',
	'tout_voir' => 'Vidi ĉiujn mesaĝojn',

	// V
	'voir_messages_objet' => 'vidi la mesaĝojn',
];

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'Neniu foruma mesaĝo',

	// B
	'bouton_radio_articles_futurs' => 'nur al estontaj artikoloj (neniu ago ĉe la datenbazo).',
	'bouton_radio_articles_tous' => 'al ĉiuj artikoloj senescepte.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'al ĉiuj artikoloj, escepte tiuj, kies forumo estas fermita.',
	'bouton_radio_enregistrement_obligatoire' => 'Deviga memregistriĝo (la uzantoj devas aboniĝi, entajpante sian retpoŝtadreson antaŭ ol sendi kontribuaĵojn).', # MODIF
	'bouton_radio_moderation_priori' => 'Apriora moderigado (kontribuaĵoj estas publikigataj nur post validigo fare de mastrumantoj).', # MODIF
	'bouton_radio_modere_abonnement' => 'per abono',
	'bouton_radio_modere_posteriori' => 'aposteriore moderigata',
	'bouton_radio_modere_priori' => 'apriore moderigata',
	'bouton_radio_publication_immediate' => 'Tujpublikigo de mesaĝoj
 (la kontribuaĵoj afiŝiĝas tuj post ties sendo, la mastrumantoj povas
forviŝi ilin poste).', # MODIF

	// D
	'documents_interdits_forum' => 'Dokumentoj malpermesitaj en la forumo',

	// E
	'erreur_enregistrement_message' => 'Via mesaĝo ne estis registrita pro teknika problemo.',
	'extensions_autorisees' => 'Eblaj sufiksoj :',
	'extensions_autorisees_toutes' => 'ĉiujn',

	// F
	'form_pet_message_commentaire' => 'Ĉu mesaĝon, ĉu komenton ?',
	'forum' => 'Forumo',
	'forum_acces_refuse' => 'Vi ne plu havas alir-rajton al tiuj ĉi forumoj.',
	'forum_attention_dix_caracteres' => '<b>Atentu !</b> via mesaĝo devas enhavi almenaŭ dek signojn.',
	'forum_attention_message_non_poste' => 'Atentu, vi ne afiŝis vian mesaĝon !',
	'forum_attention_nb_caracteres_mini' => '<b>Atentu !</b> Via mesaĝo enhavu almenaŭ @min@ signoj.',
	'forum_attention_trois_caracteres' => '<b>Atentu !</b> via titolo devas enhavi almenaŭ tri signojn.',
	'forum_attention_trop_caracteres' => '<b>Atentu !</b> Via mesaĝo estas tro longa (@compte@ signoj) : por esti registrita, ĝi ne preteratingu @max@ signojn.',
	'forum_avez_selectionne' => 'Vi selektis :',
	'forum_cliquer_retour' => 'Musklaku <a href=\'@retour_forum@\'>ĉi tie</a> por daŭrigi.',
	'forum_envoyer' => 'Sendi',
	'forum_forum' => 'forumo',
	'forum_info_modere' => 'Tiu ĉi forumo estas apriore moderigata : via kontribuo aperos nur post validigo fare de mastrumanto de la retejo.', # MODIF
	'forum_lien_hyper' => 'Retligilo',
	'forum_message' => 'Via mesaĝo',
	'forum_message_definitif' => 'Definitiva mesaĝo : sendu al la forumo',
	'forum_message_trop_long' => 'Via mesaĝo estas tro longa. Ĝi maksimume estu 20 000 signojn longa.',
	'forum_ne_repondez_pas' => 'Ne respondu al tiu ĉi retletero, sed en la forumo ĉe la jena adreso :',
	'forum_page_url' => '(Se via mesaĝo rilatas al artikolo publikigita ĉe la reto, aŭ al paĝo donanta pli da informoj, bonvolu indiki ĉi-poste la titolon de la paĝo kaj ties ret-adreson.)',
	'forum_permalink' => 'Fiksligilo al la komento',
	'forum_poste_par' => 'Mesaĝo skribita de @parauteur@ reage al la artikolo „@titre@“.',
	'forum_poste_par_court' => 'Mesaĝo afiŝita@parauteur@.',
	'forum_poste_par_generique' => 'Mesaĝo afiŝita@parauteur@ (@objet@ „@titre@“).',
	'forum_qui_etes_vous' => 'Kiu vi estas ?',
	'forum_saisie_texte_info' => 'Tiu formularo komprenas la jenajn SPIP-markojn : <code>[-&gt;retadreso] {{grasa}} {kursiva} &lt;quote&gt; &lt;code&gt;</code> kaj HTML-markojn : <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Por krei alineoj, simple lasu malplenajn liniojn.',
	'forum_texte' => 'Teksto de via mesaĝo',
	'forum_titre' => 'Titolo',
	'forum_url' => 'Via retejo',
	'forum_valider' => 'Validigi tiun elekton',
	'forum_voir_avant' => 'Antaŭrigardi',
	'forum_votre_email' => 'Via retpoŝtadreso',
	'forum_votre_nom' => 'Via nomo',
	'forum_vous_enregistrer' => 'Por partopreni en ;
  tiu ĉi forumo, vi devas antaŭe registriĝi. Bonvolu
  indiki ĉi-sube la personan ensalutilon kiu estis
  sendita al vi. Se vi ne estas registrita, vi devas',
	'forum_vous_inscrire' => 'registriĝi.',

	// I
	'icone_bruler_message' => 'Raporti kiel trudmesaĝo',
	'icone_bruler_messages' => 'Raporti kiel trudmesaĝo',
	'icone_legitimer_message' => 'Raporti kiel taŭga mesaĝo',
	'icone_poster_message' => 'Sendi mesaĝon',
	'icone_suivi_forum' => 'Superrigardo de la publika forumo : @nb_forums@ kontribuo(j)',
	'icone_suivi_forums' => 'Superrigardi/mastrumi la forumojn',
	'icone_supprimer_message' => 'Forigi tiun mesaĝon',
	'icone_supprimer_messages' => 'Forigi tiujn mesaĝojn',
	'icone_valider_message' => 'Validigi tiun mesaĝon',
	'icone_valider_messages' => 'Validigi tiujn mesaĝojn',
	'icone_valider_repondre_message' => 'Validigi kaj respondi tiun mesaĝon',
	'info_1_message_forum' => '1 foruma mesaĝo',
	'info_activer_forum_public' => 'Por aktivigi la publikajn forumojn, bonvolu elekti ilian
 defaŭltan moderig-reĝimon :',
	'info_appliquer_choix_moderation' => 'Apliki tiun moderig-elekton :',
	'info_config_forums_prive' => 'En la privata spaco de la retejo, vi povas aktivigi plurajn tipojn de forumoj :',
	'info_config_forums_prive_admin' => 'Forumo rezervita al retejaj mastrumantoj :', # MODIF
	'info_config_forums_prive_global' => 'Ĝenerala forumo, malfermita al ĉiuj redaktantoj :', # MODIF
	'info_config_forums_prive_objets' => 'Forumo sub ĉiu artikolo, fulminformo, referencigita retejo, ktp :',
	'info_desactiver_forum_public' => 'Malaktivigi la uzon de la publikaj forumoj.
La publikaj forumoj estos laŭkaze unu post la alia permesitaj
 laŭ la artikoloj ; ili estos malpermesataj koncerne rubrikojn, fulm-informojn, ktp.',
	'info_envoi_forum' => 'Sendo de la forumoj al aŭtoroj de la artikoloj', # MODIF
	'info_fonctionnement_forum' => 'Funkciado de la forumo :',
	'info_forcer_previsualisation_court' => 'Devigi la antaŭrigardon',
	'info_forcer_previsualisation_long' => 'Devigi la antaŭrigardon antaŭ sendo de la mesaĝo',
	'info_forums_liees_mot' => 'Mesaĝoj el forumo ligitaj al tiu ĉi vorto',
	'info_gauche_suivi_forum_2' => 'La paĝo pri <i>superkontrolo de la forumoj</i> estas mastrumilo por via retejo (kaj ne diskutejo aŭ redaktejo). Ĝi afiŝas ĉiujn kontribuaĵojn de la forumoj (de la publika spaco same kiel de la privata), kaj ebligas al vi mastrumi tiujn kontribuaĵojn.',
	'info_liens_syndiques_3' => 'forumoj',
	'info_liens_syndiques_4' => 'estas',
	'info_liens_syndiques_5' => 'forumo',
	'info_liens_syndiques_6' => 'estas',
	'info_liens_syndiques_7' => 'validigotaj',
	'info_liens_texte' => 'Ligilo(j) ene de la teksto de la mesaĝo',
	'info_liens_titre' => 'Ligilo(j) ene de la titolo de la mesaĝo',
	'info_mode_fonctionnement_defaut_forum_public' => 'Defaŭlta funkcimodo de la publikaj forumoj',
	'info_nb_messages_forum' => '@nb@ forummesaĝoj',
	'info_option_email' => 'Kiam vizitanto de la retejo sendas novan mesaĝon en la forumon
 ligitan kun artikolo, eblas retpoŝte sciigi pri tiu mesaĝo al la aŭtoroj de la artikolo. Indiku por ĉia forumo, ĉu tiun eblecon oni uzu.', # MODIF
	'info_pas_de_forum' => 'neniu forumo',
	'info_question_visiteur_ajout_document_forum' => 'Se vi deziras permesi al vizitantoj kunsendi dokumentojn (bildojn, sonaĵojn...) al siaj forumaj mesaĝoj, bonvolu indiki ĉi-sube la liston de dosiernomaj sufiksoj permesitaj por la forumoj (ekz. : gif, jpg, png, mp3).', # MODIF
	'info_question_visiteur_ajout_document_forum_format' => 'Se vi deziras permesi ĉiujn tipojn de dokumentoj konsideritaj kiel sekuraj de Spip, entajpu steleton. Por nenion permesi, nenion entajpu.',
	'info_selectionner_message' => 'Elekti la mesaĝojn :',
	'interface_formulaire' => 'Formulara interfaco',
	'interface_onglets' => 'Interfaco kun langetoj',
	'item_activer_forum_administrateur' => 'Aktivigi la forumon de la mastrumantoj', # MODIF
	'item_config_forums_prive_global' => 'Aktivigi la forumon de redaktantoj', # MODIF
	'item_config_forums_prive_objets' => 'Aktivigi tiujn ĉi forumojn',
	'item_desactiver_forum_administrateur' => 'Malaktivigi la forumon de la mastrumantoj', # MODIF
	'item_non_config_forums_prive_global' => 'Malaktivigi la forumon de redaktantoj', # MODIF
	'item_non_config_forums_prive_objets' => 'Malaktivigi tiujn ĉi forumojn',

	// L
	'label_selectionner' => 'Elekti :',
	'lien_reponse_article' => 'Respondo al la artikolo',
	'lien_reponse_breve_2' => 'Respondo al la fulm-informo',
	'lien_reponse_message' => 'Respondi al mesaĝo',
	'lien_reponse_rubrique' => 'Respondo al la rubriko',
	'lien_reponse_site_reference' => 'Respondo al la referencigita retejo',
	'lien_vider_selection' => 'Malplenigi la elekton',

	// M
	'messages_aucun' => 'Neniu',
	'messages_meme_auteur' => 'Ĉiuj mesaĝoj el tiu aŭtoro', # MODIF
	'messages_meme_email' => 'Ĉiuj mesaĝoj el tiu retmesaĝo',
	'messages_meme_ip' => 'Ĉiuj mesaĝoj el tiu IP-adreso',
	'messages_off' => 'Forigitaj',
	'messages_perso' => 'Personaj',
	'messages_privadm' => 'Mastrumantoj', # MODIF
	'messages_prive' => 'Privataj',
	'messages_privoff' => 'Forigitaj',
	'messages_privrac' => 'Ĝeneralaj',
	'messages_prop' => 'Proponitaj',
	'messages_publie' => 'Publikigitaj',
	'messages_spam' => 'Trudmesaĝo',
	'messages_tous' => 'Ĉiuj',

	// O
	'onglet_messages_internes' => 'Internaj mesaĝoj',
	'onglet_messages_publics' => 'Publikaj mesaĝoj',
	'onglet_messages_vide' => 'Sentekstaj mesaĝoj',

	// R
	'repondre_message' => 'Respondi al tiu mesaĝo',

	// S
	'statut_off' => 'Forigita',
	'statut_original' => 'originala',
	'statut_prop' => 'Proponita',
	'statut_publie' => 'Publikigita',
	'statut_spam' => 'Trudmesaĝo',

	// T
	'text_article_propose_publication_forum' => 'Senhezite sciigu vian opinion danke al forumo ligita al tiu artikolo (sube de la paĝo).',
	'texte_en_cours_validation' => 'Ĉi-subaj artikoloj, fulm-informoj, forumoj estas proponitaj por publikigo.',
	'texte_en_cours_validation_forum' => 'Senhezite sciigu vian opinion danke al forumoj, kiuj estas ligitaj al ili.',
	'texte_messages_publics' => 'Publikaj mesaĝoj pri :',
	'titre_cadre_forum_administrateur' => 'Privata forumo de la mastrumantoj', # MODIF
	'titre_cadre_forum_interne' => 'Interna forumo',
	'titre_config_forums_prive' => 'Forumoj de la privata spaco',
	'titre_forum' => 'Forumo',
	'titre_forum_suivi' => 'Superrigardo de la forumoj',
	'titre_page_forum_suivi' => 'Superrigardo de la forumoj',
	'titre_selection_action' => 'Elekto',
	'tout_voir' => 'Vidi ĉiujn mesaĝojn',

	// V
	'voir_messages_objet' => 'vidi la mesaĝojn',
];
